<?xml version="1.0" ?>

<!--Description:

 Leverage the translation from an existing XLIFF document into a new one.

Usage:

 C:\>msxsl <newfile> LeverageXLIFF.xsl Prev=<prevfile> Trg=<trgcode> > <updatedfile>
 Where <newfile> is the latest XLIFF document to translate, <prevdoc> is the XLIFF
 document previously translated, <trgcode> is the ISO locale codes for the target
 language, and <updatedfile> is the leveraged XLIFF document.

Example:

 C:\>msxsl Data_v2.xlf LeverageXLIFF.xsl Prev=Data_v1.xlf Trg=ja-JP > updated.xlf

Notes:

 Any existing content in <target> in the input file will be ignored.

-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 version="1.0">

 <xsl:output encoding="utf-8" indent="yes"/>
 <xsl:param name="Prev"></xsl:param>
 <xsl:param name="Trg"></xsl:param>

 <xsl:template match="node()|@*">
  <xsl:copy>
   <xsl:apply-templates select="node()|@*"/>
  </xsl:copy>
 </xsl:template>

 <xsl:template match="target"/>

 <xsl:template match="source">
  <xsl:copy>
   <xsl:apply-templates select="node()|@*"/>
  </xsl:copy>
  <xsl:variable name="UnitID">
   <xsl:value-of select="../@resname"/>
  </xsl:variable>
  <xsl:variable name="Match">
   <xsl:value-of select="document($Prev)//trans-unit[@resname=$UnitID]/source"/>
  </xsl:variable>
  <xsl:element name="target">
   <xsl:attribute name="xml:lang">
    <xsl:value-of select="$Trg"/>
   </xsl:attribute>
   <xsl:choose>
    <xsl:when test="$Match=.">
     <xsl:variable name="Trans">
      <xsl:value-of select="document($Prev)//trans-unit[@resname=$UnitID]/target"/>
     </xsl:variable>
     <xsl:choose>
      <xsl:when test="$Trans=''">
       <xsl:value-of select="."/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="$Trans"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="."/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:element>
 </xsl:template>

</xsl:stylesheet>
